@@ -2,14 +2,14 @@
 
 from typing import TYPE_CHECKING
 
-__version__ = "0.6.1"
+__version__ = "0.7.0"
 
 if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 
 def setup(app: "Sphinx") -> dict:
-    from .extension import setup_extension
+    from .extension import setup_extension  # noqa: PLC0415
 
     setup_extension(app)
     return {
