@@ -1,12 +1,14 @@
+from contextlib import contextmanager
+from functools import partial
 import hashlib
 from pathlib import Path
 
 from docutils import nodes
 from docutils.parsers.rst import directives
+from sphinx import version_info as sphinx_version
 from sphinx.application import Sphinx
 from sphinx.environment import BuildEnvironment
 from sphinx.transforms import SphinxTransform
-from sphinx.util.docutils import SphinxDirective
 
 from . import compiled as static_module
 from ._compat import findall, read_text
@@ -16,7 +18,12 @@ from .cards import setup_cards
 from .dropdown import setup_dropdown
 from .grids import setup_grids
 from .icons import setup_icons
-from .shared import PassthroughTextElement, create_component
+from .shared import (
+    PassthroughTextElement,
+    SdDirective,
+    create_component,
+    setup_custom_directives,
+)
 from .tabs import setup_tabs
 
 
@@ -37,17 +44,36 @@ def setup_extension(app: Sphinx) -> None:
         man=(visit_depart_null, visit_depart_null),
         texinfo=(visit_depart_null, visit_depart_null),
     )
-    app.add_directive(
-        "div", Div, override=True
-    )  # override sphinx-panels implementation
-    app.add_transform(AddFirstTitleCss)
-    setup_badges_and_buttons(app)
-    setup_cards(app)
-    setup_grids(app)
-    setup_dropdown(app)
-    setup_icons(app)
-    setup_tabs(app)
-    setup_article_info(app)
+    with capture_directives(app) as directive_map:
+        app.add_directive("div", Div, override=True)
+        app.add_transform(AddFirstTitleCss)
+        setup_badges_and_buttons(app)
+        setup_cards(app)
+        setup_grids(app)
+        setup_dropdown(app)
+        setup_icons(app)
+        setup_tabs(app)
+        setup_article_info(app)
+
+    app.add_config_value("sd_custom_directives", {}, "env")
+    app.connect(
+        "config-inited", partial(setup_custom_directives, directive_map=directive_map)
+    )
+
+
+@contextmanager
+def capture_directives(app: Sphinx):
+    """Capture the directives that are registered by the extension."""
+    directive_map = {}
+    add_directive = app.add_directive
+
+    def _add_directive(name, directive, **kwargs):
+        directive_map[name] = directive
+        add_directive(name, directive, **kwargs)
+
+    app.add_directive = _add_directive
+    yield directive_map
+    app.add_directive = add_directive
 
 
 def update_css_js(app: Sphinx):
@@ -67,9 +93,14 @@ def update_css_js(app: Sphinx):
         js_path.write_text(content)
     # Read the css content and hash it
     content = read_text(static_module, "style.min.css")
-    hash = hashlib.md5(content.encode("utf8")).hexdigest()
     # Write the css file
-    css_path = static_path / f"design-style.{hash}.min.css"
+    if sphinx_version < (7, 1):
+        hash = hashlib.md5(content.encode("utf8"), usedforsecurity=False).hexdigest()
+        css_path = static_path / f"sphinx-design.{hash}.min.css"
+    else:
+        # since sphinx 7.1 a checksum is added to the css file URL, so there is no need to do it here
+        # https://github.com/sphinx-doc/sphinx/pull/11415
+        css_path = static_path / "sphinx-design.min.css"
     app.add_css_file(css_path.name)
     if css_path.exists():
         return
@@ -105,7 +136,7 @@ def visit_depart_null(self, node: nodes.Element) -> None:
     """visit/depart passthrough"""
 
 
-class Div(SphinxDirective):
+class Div(SdDirective):
     """Same as the ``container`` directive,
     but does not add the ``container`` class in HTML outputs,
     which can interfere with Bootstrap CSS.
@@ -116,17 +147,16 @@ class Div(SphinxDirective):
     option_spec = {"style": directives.unchanged, "name": directives.unchanged}
     has_content = True
 
-    def run(self):
+    def run_with_defaults(self) -> list[nodes.Node]:
         try:
             if self.arguments:
                 classes = directives.class_option(self.arguments[0])
             else:
                 classes = []
-        except ValueError:
+        except ValueError as exc:
             raise self.error(
-                'Invalid class attribute value for "%s" directive: "%s".'
-                % (self.name, self.arguments[0])
-            )
+                f'Invalid class attribute value for "{self.name}" directive: "{self.arguments[0]}".'
+            ) from exc
         node = create_component("div", rawtext="\n".join(self.content), classes=classes)
         if "style" in self.options:
             node["style"] = self.options["style"]
