@@ -1,7 +1,7 @@
 """Test the documented snippets run correctly, and are the same for both RST and MyST."""
 
+from collections.abc import Callable
 from pathlib import Path
-from typing import Callable
 
 import pytest
 
@@ -33,7 +33,10 @@ def write_assets(src_path: Path):
     ids=[path.name[: -len(path.suffix)] for path in SNIPPETS_GLOB_RST],
 )
 def test_snippets_rst(
-    sphinx_builder: Callable[..., SphinxBuilder], path: Path, file_regression
+    sphinx_builder: Callable[..., SphinxBuilder],
+    path: Path,
+    file_regression,
+    normalize_doctree_xml,
 ):
     """Test snippets written in RestructuredText (before post-transforms)."""
     builder = sphinx_builder(conf_kwargs={"extensions": ["sphinx_design"]})
@@ -44,8 +47,8 @@ def test_snippets_rst(
     doctree = builder.get_doctree("index", post_transforms=False)
     doctree.attributes.pop("translation_progress", None)  # added in sphinx 7.1
     file_regression.check(
-        doctree.pformat(),
-        basename=f"snippet_pre_{path.name[:-len(path.suffix)]}",
+        normalize_doctree_xml(doctree.pformat()),
+        basename=f"snippet_pre_{path.name[: -len(path.suffix)]}",
         extension=".xml",
         encoding="utf8",
     )
@@ -58,7 +61,10 @@ def test_snippets_rst(
 )
 @pytest.mark.skipif(not MYST_INSTALLED, reason="myst-parser not installed")
 def test_snippets_myst(
-    sphinx_builder: Callable[..., SphinxBuilder], path: Path, file_regression
+    sphinx_builder: Callable[..., SphinxBuilder],
+    path: Path,
+    file_regression,
+    normalize_doctree_xml,
 ):
     """Test snippets written in MyST Markdown (before post-transforms)."""
     builder = sphinx_builder()
@@ -69,8 +75,8 @@ def test_snippets_myst(
     doctree = builder.get_doctree("index", post_transforms=False)
     doctree.attributes.pop("translation_progress", None)  # added in sphinx 7.1
     file_regression.check(
-        doctree.pformat(),
-        basename=f"snippet_pre_{path.name[:-len(path.suffix)]}",
+        normalize_doctree_xml(doctree.pformat()),
+        basename=f"snippet_pre_{path.name[: -len(path.suffix)]}",
         extension=".xml",
         encoding="utf8",
     )
@@ -82,7 +88,10 @@ def test_snippets_myst(
     ids=[path.name[: -len(path.suffix)] for path in SNIPPETS_GLOB_RST],
 )
 def test_snippets_rst_post(
-    sphinx_builder: Callable[..., SphinxBuilder], path: Path, file_regression
+    sphinx_builder: Callable[..., SphinxBuilder],
+    path: Path,
+    file_regression,
+    normalize_doctree_xml,
 ):
     """Test snippets written in RestructuredText (after HTML post-transforms)."""
     builder = sphinx_builder(conf_kwargs={"extensions": ["sphinx_design"]})
@@ -93,8 +102,8 @@ def test_snippets_rst_post(
     doctree = builder.get_doctree("index", post_transforms=True)
     doctree.attributes.pop("translation_progress", None)  # added in sphinx 7.1
     file_regression.check(
-        doctree.pformat(),
-        basename=f"snippet_post_{path.name[:-len(path.suffix)]}",
+        normalize_doctree_xml(doctree.pformat()),
+        basename=f"snippet_post_{path.name[: -len(path.suffix)]}",
         extension=".xml",
         encoding="utf8",
     )
@@ -107,7 +116,10 @@ def test_snippets_rst_post(
 )
 @pytest.mark.skipif(not MYST_INSTALLED, reason="myst-parser not installed")
 def test_snippets_myst_post(
-    sphinx_builder: Callable[..., SphinxBuilder], path: Path, file_regression
+    sphinx_builder: Callable[..., SphinxBuilder],
+    path: Path,
+    file_regression,
+    normalize_doctree_xml,
 ):
     """Test snippets written in MyST Markdown (after HTML post-transforms)."""
     builder = sphinx_builder()
@@ -118,8 +130,8 @@ def test_snippets_myst_post(
     doctree = builder.get_doctree("index", post_transforms=True)
     doctree.attributes.pop("translation_progress", None)  # added in sphinx 7.1
     file_regression.check(
-        doctree.pformat(),
-        basename=f"snippet_post_{path.name[:-len(path.suffix)]}",
+        normalize_doctree_xml(doctree.pformat()),
+        basename=f"snippet_post_{path.name[: -len(path.suffix)]}",
         extension=".xml",
         encoding="utf8",
     )
@@ -164,7 +176,7 @@ def test_sd_hide_title_myst(
 
 @pytest.mark.skipif(not MYST_INSTALLED, reason="myst-parser not installed")
 def test_sd_custom_directives(
-    sphinx_builder: Callable[..., SphinxBuilder], file_regression
+    sphinx_builder: Callable[..., SphinxBuilder], file_regression, normalize_doctree_xml
 ):
     """Test that the defaults are used."""
     builder = sphinx_builder(
@@ -188,7 +200,7 @@ def test_sd_custom_directives(
     doctree = builder.get_doctree("index", post_transforms=False)
     doctree.attributes.pop("translation_progress", None)  # added in sphinx 7.1
     file_regression.check(
-        doctree.pformat(),
+        normalize_doctree_xml(doctree.pformat()),
         basename="sd_custom_directives",
         extension=".xml",
         encoding="utf8",
